#!/bin/bash

#export NCCL_DEBUG=INFO
export NCCL_SOCKET_IFNAME=bond0
export NCCL_IB_HCA=mlx5_0,mlx5_1,mlx5_5,mlx5_6

export OMP_NUM_THREADS=12

export MODEL_DIR=/mnt/data/hfcache/DeepSeek-R1
export MODEL_NAME=DeepSeek-R1

export VLLM_IMAGE=vllm-openai_v0.8.1.sif
#export VLLM_API_KEY="password"
export VLLM_HOST_IP=$(hostname | xargs gethostip | awk '{print $2}')

RAY_START_CMD="ray start "
if [ $SLURM_NODEID == 0 ]; then
    RAY_START_CMD+=" --head --port=6379"
else
    RAY_START_CMD+=" --block --address=$MASTER_ADDR:6379"
fi

echo $SLURM_NODEID,$RAY_START_CMD

apptainer instance start --nv --no-home --writable-tmpfs \
    -B $MODEL_DIR:/root/.cache/huggingface \
    $VLLM_IMAGE app-instance

apptainer exec instance://app-instance $RAY_START_CMD

sleep 15

if [ $SLURM_NODEID == 0 ]; then
    apptainer exec instance://app-instance \
        vllm serve \
        /root/.cache/huggingface \
        --served-model-name "$MODEL_NAME" \
        --host 0.0.0.0 \
        --port 8000 \
        --tensor-parallel-size 8 \
        --pipeline-parallel-size $SLURM_NNODES \
        --max-model-len 65536 \
        --max_num_seqs=32 \
        --gpu_memory_utilization 0.9 \
        --enable-prefix-caching \
        --enable-chunked-prefill \
        --max_num_batched_tokens 65536 \
        --trust-remote-code
fi
